@@ -115,7 +115,7 @@ def add_sections(data, threads, json_filepath=None):
     eclis = data.loc[:, 'ECLI']
     length = celex.size
     time.sleep(1)
-    bar = tqdm(total=length, colour="GREEN")
+    bar = tqdm(total=length, colour="GREEN", miniters=int(length/100), position=0, leave=True, maxinterval=10000)
     if length > threads:  # to avoid getting problems with small files
         at_once_threads = int(length / threads)
     else:
@@ -173,6 +173,6 @@ Used for adding columns easier to a dataframe for add_sections().
 def add_column_frow_list(data, name, list):
     column = pd.Series([], dtype='string')
     for l in list:
-        column = column.append(l)
+        column = pd.concat([column,l])
     column.sort_index(inplace=True)
     data.insert(1, name, column)
